/*
	SANST8IN.H - Streaming Device Driver (S508) User Interface Header
	Copyright (c) 1996 Sangoma Technologies Inc.
	v1.00 May/96

	Set tabs to 4 spaces when viewing.
*/

//
// DeviceIoControl command codes. Must include "winioctl.h" in app for
// definition of CTL_CODE and defines.
//

// Standard CBLOCK-passing command:
// Input: ptr to STREAMING_CBLOCK structure
// Output: ptr to STREAMING_CBLOCK structure (may be same as input)
// Uses Buffered I/O. Synchronous call.
#define IoctlCodeCblockCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 10, METHOD_BUFFERED, FILE_ANY_ACCESS)

// Command to send a frame:
// Input: ptr to STREAMING_CBLOCK structure
// Output: ptr to STREAMING_CBLOCK structure (may be same as input)
// Uses Direct I/O (Irp->MdlAddress). Synchronous call.
// Note: Frame only queued for transmission when ReturnCode is 0x00. If not,
//       must repeat this command with reinitialized structure.
//       The Command member need not be initialized.
#define IoctlCodeWriteCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 11, METHOD_OUT_DIRECT, FILE_ANY_ACCESS)

// Command to read a frame:
// Input: NULL
// Output: ptr to STREAMING_READ_INFO (plus adequate data storage area)
// Uses Direct I/O (Irp->MdlAddress). Blocking call on device handle.
// Note: Since this command blocks all further I/O requests, it must be done
//       on a separate device handle. Just open the same device again and use
//       this handle for reading.
#define IoctlCodeReadCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 12, METHOD_IN_DIRECT, FILE_ANY_ACCESS)

// Command to retrieve status information:
// Input: NULL
// Output: ptr to STREAMING_STATUS_INFO structure
// Uses Buffered I/O. Synchronous call.
#define IoctlCodeStatusCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 13, METHOD_BUFFERED, FILE_ANY_ACCESS)

//
// ===== MAILBOX COMMANDS =====
// For use with IoctlCodeCblockCommand.
//
#define READ_STATUS                    0x00
#define ENABLE_COMMUNICATIONS          0x03
#define DISABLE_COMMUNICATIONS         0x04	// also terminates IoctlCodeReadCommand if pending
#define SET_CONFIGURATION              0x05
#define READ_CONFIGURATION             0x06
#define READ_OPERATIONAL_STATISTICS    0x07
#define FLUSH_OPERATIONAL_STATISTICS   0x08
#define READ_COMMS_ERR_STATISTICS      0x09
#define FLUSH_COMMS_ERR_STATISTICS     0x0A
#define SET_MODEM_STATUS               0x0B
#define READ_MODEM_STATUS              0x0C
#define FLUSH_BUFFERS                  0x0D	// not to be used
#define READ_CODE_VERSION              0x10
#define BRIDGE_RX_AND_TX               0x11
#define SET_INTERRUPT_TRIGGERS         0x20	// not to be used
#define READ_INTERRUPT_TRIGGERS        0x21
#define RX_CRC_FRAME_CONTROL           0x22

//
// Driver-defined return codes for CBLOCK-associated commands.
//
#define RCODE_TIMEOUT_ERROR		0x7f	// Card is not responding to command.
#define RCODE_INIT_ERROR		0x7e	// Card could not be initialized.
										// (SET_CONFIGURATION only)

//
// All structures below must be packed on 1-byte boundaries.
//

#pragma pack(1)

//
// Control block structure used for IoctlCodeCblockCommand and
// IoctlCodeWriteCommand, as input and output data.
//
typedef struct _STREAMING_CBLOCK {
	UCHAR OpFlag;			// internal use only
	UCHAR Command;			// frame relay command code
	USHORT BufferLength;	// length of data associated with command
	UCHAR ReturnCode;		// return code
	UCHAR reserved[11];
	UCHAR Data[1];			// variable-length array containing data
} STREAMING_CBLOCK, *PSTREAMING_CBLOCK;

//
// May be used as an aid for filling in the data area of the
// SET_CONFIGURATION command. See printed manual.
//
typedef struct _STREAMING_CONFIG {
	ULONG BaudRateBps;
	USHORT MaxFrameSize;
	USHORT PercentTransmitBuffers;
	USHORT OperationalBits;
	USHORT ModemBits;
	USHORT StatisticsBits;
	ULONG AdapterFrequency;
} STREAMING_CONFIG, *PSTREAMING_CONFIG;

//
// Information returned by IoctlCodeStatusCommand.
// See printed manual section on interface area bytes.
//
typedef struct _STREAMING_STATUS_INFO {
	UCHAR BasePortRegister;			// contents of base port register
	UCHAR ModemStatusByte;			// contents of modem status byte
} STREAMING_STATUS_INFO, *PSTREAMING_STATUS_INFO;

//
// Equivalent to Receive Status Element in Manual.
// Data of variable length follows.
//
typedef struct _STREAMING_READ_INFO {
	UCHAR Status;					// set to 0x01 on return if frame read
	USHORT FrameLength;				// set to length of frame that follows
	UCHAR MiscBits;					// various frame-related bits
	USHORT TimeStamp;				// timestamp of frame
	UCHAR Reserved[10];
	UCHAR Data[1];					// variable-length frame data
} STREAMING_READ_INFO, *PSTREAMING_READ_INFO;

#pragma pack()


